==> acomea.contact-0.1.tar.gz: acomea.contact-0.1/acomea/contact/utils/update.py <==
# coding: utf-8
"""
contacts update utils
"""
import logging
import datetime

from django.db import connection, DatabaseError, IntegrityError
from django.db.models import Q
from django.contrib.auth.models import User
from django.core.exceptions import ObjectDoesNotExist
from django.conf import settings

from acomea.contact.models import Contact, Email
from acomea.profilo.models import AcomeaProfilo

log = logging.getLogger("acomea.contact")


def update_from_user():
    """
    aggiorna le entries del modello 'contact' con le
    corrispondenze del modello User
    """
    users_with_email = User.objects.exclude(email__exact="")
    counter = 0
    profilo_dne = 0
    for user in users_with_email:
        try:
            email = Email.objects.get(email=user.email)
            contact = email.contact
            contact.user = user
            for _email in contact.emails.exclude(email__exact=user.email):
                _email.default = False
                _email.save()
            email.default = True
            email.save()
            contact.save()

        except Email.DoesNotExist:
            print "Email object w/ email: %s does not exist" % user.email
            continue

        # controllo in piu' (c'è già l'unique=True nel campo 'email'
        # del modello Email)
        except Email.MultipleObjectsReturned:
            print "Multiple Email object w/ email: %s" % user.email
            continue

        contact.auth_trattamento_dati = True

        # bonifica aut. invio mat. commerciale: se il contact ha la data di
        # disiscrizione a None, metto a True auth_materiale_commerciale
        if contact.date_unsubscription is None:
            contact.auth_materiale_commerciale = True

        contact.bonifica = True
        contact.save()

        try:
            if user.profilo:
                contact.auth_materiale_commerciale = user.profilo.auth_analisi
                contact.auth_societa_terze = user.profilo.auth_societa_terze
                contact.save()
                counter += 1
        except AcomeaProfilo.DoesNotExist:
            print "l'utente %s non ha alcun profilo associato" % user.username
            profilo_dne += 1
            continue
    # print "Aggiornati %d contatti da users" % counter
    print "utenti con profili associati aggiornati: %d" % counter
    print "utenti senza profili associati: %d" % profilo_dne


def set_bonifica(contact):
    """
    setta il flag "bonifica" dell'instanca contact (devono essere True sia 'auth_trattamento_dati',
    sia 'auth_materiale_commerciale'
    :param contact_instance: instance of Contact object
    """
    try:
        contact.bonifica = contact.auth_trattamento_dati and contact.auth_materiale_commerciale
        contact.save()
    except DatabaseError as e:
        log.error("Errore bonifica contatto id %d - errore: %s" % (contact.id, e.message))
        pass



def set_contact_in_registration(user, cleaned_data):
    """
    setta la OneToOne allo User per l'istanza contact al termine della registrazione:
    - se c'è già un Contact con la email dello user, recupero e effettua l'associazione
    - se non c'è, crea un nuovo contatto con quella mail e associo lo user
    in entrambe i casi il gruppo associato sarà 'Utenti Registrati AR'.
    :param user: istanza oggetto User
    """
    try:
        email = Email.objects.get(email=cleaned_data.get('email', None))
    except Email.DoesNotExist:
        email = Email(email=cleaned_data.get('email', None))
    try:
        contact = email.contact
    except Contact.DoesNotExist:
        contact = Contact()
    contact.first_name = user.first_name
    contact.last_name = user.last_name
    auth_trattamento_dati = cleaned_data.get('auth_trattamento_dati', False)
    contact.auth_trattamento_dati = True if auth_trattamento_dati == "True" else False
    auth_materiale_commerciale = cleaned_data.get('auth_materiale_commerciale', False)
    contact.auth_materiale_commerciale = True if auth_materiale_commerciale == "True" else False
    auth_societa_terze = cleaned_data.get('auth_societa_terze', False)
    contact.auth_societa_terze = True if auth_societa_terze == "True" else False
    if contact.pk is None:
       contact.bonifica = False
    contact.save()
    email.default = True

    try:
        contact.emails.add(email)

    except IntegrityError, e:
        log.debug(
            "email %s gia' associata al "
            "contatto %s" % (
                email.email,
                str(contact.id)
            )
        )
    try:
        contact.user = user
        contact.save()
    except (IntegrityError, DatabaseError) as e:
        log.error(
            "errore associazione contact %s con "
            "user %s. errore: %s" % (
                str(contact),
                str(user),
                e.message
            )
        )
    update_date_subscription_and_email(contact)


def update_date_subscription_and_email(contact, is_lead_registration=False):
    """

    :param contact:
    :param is_lead_registration:
    :return:
    """
    if not is_lead_registration:
        # fixme:
        # da verificare -> se non si è nel form di registrazione, setta la data di
        # sottoscrizione e salva il contatto
        contact.date_subscription = datetime.datetime.now()
        return
    try:
        user = contact.user
        profilo = user.profilo
    except User.DoesNotExist:
        log.debug(
            "contatto %d non ha associato alcuno user" %
            contact.id
        )
        return
    except AcomeaProfilo.DoesNotExist:
        log.debug(
            "utente %s non ha associato alcun profilo" %
            user.username
        )
        return
    # iscrizione_alla_newsletter = contact.user.profilo.iscrizione_alla_newsletter
    auth_materiale_commerciale = contact.auth_materiale_commerciale
    if auth_materiale_commerciale:
        contact.date_subscription = datetime.datetime.now()
        contact.save()


def set_new_contact_for_user(user):
    """
    Associa un nuovo contatto ad uno user. se lo user ha già
    un contatto associato, verrà sovrascritto
    :param user:
    :return: contact
    """
    contact = Contact()
    contact.first_name = user.first_name
    contact.last_name = user.last_name
    try:
        email = Email.objects.get(email=user.email)
    except Email.DoesNotExist:
        email = Email(email=user.email)
    email.default = True
    email.save()
    contact.emails.add(email)
    contact.user = user
    contact.save()
    return contact


def bonifica_contact_groups_from_rac(queryset=None):
    """
    setta i gruppi contatto "CLIENTE_DISP", "CLIENTE_CONS",
    "Lead", "Utenti Registrati AR" in base allo stato rac e
    al flag profilo is_lead
    :param queryset: rac queryset

    """
    # inside function imports to avoid possible circular imports
    from acomea.contact.models import Group, Contact
    if settings.DEBUG:
        print(
            'bonifica_contact_groups_from_rac - start %s' %
            datetime.datetime.now().strftime("%d/%m/%Y %X")
        )
    else:
        log.info(
            'bonifica_contact_groups_from_rac - start %s' %
            datetime.datetime.now().strftime("%d/%m/%Y %X")
        )
    if not queryset:
        from acomea.profilo.models import RichiestaAttivazioneCliente
        queryset = RichiestaAttivazioneCliente.objects.filter(
            Q(stato__in=('6', '9')) | Q(profilo__is_lead=True)
        )
    group_clienti_disp, c = Group.objects.get_or_create(
        name__iexact="CLIENTI_DISP"
    )
    group_clienti_cons, c = Group.objects.get_or_create(
        name__iexact="CLIENTI_CONS"
    )
    group_utenti_registrati_ar, c = Group.objects.get_or_create(
        name__iexact="Utenti Registrati AR"
    )
    group_lead, c = Group.objects.get_or_create(
        name__iexact="Lead"
    )
    for rac in queryset:
        try:
            if rac.stato == "6":
                rac.profilo.user.contact.groups.add(
                    group_clienti_cons
                )
                rac.profilo.user.contact.groups.remove(
                    group_clienti_disp, group_lead
                )
            elif rac.stato == "9":
                rac.profilo.user.contact.groups.add(
                    group_clienti_disp,
                )
                rac.profilo.user.contact.groups.remove(
                    group_clienti_cons, group_lead
                )
            elif rac.profilo.is_lead:
                rac.profilo.user.contact.groups.add(
                    group_lead
                )
            rac.profilo.user.contact.groups.add(
                group_utenti_registrati_ar
            )
        except ObjectDoesNotExist:
            continue
    if settings.DEBUG:
        print(
            'bonifica_contact_groups_from_rac - end %s' %
            datetime.datetime.now().strftime("%d/%m/%Y %X")
        )
    else:
        log.info(
            'bonifica_contact_groups_from_rac - end %s' %
            datetime.datetime.now().strftime("%d/%m/%Y %X")
        )

==> acomea.contact-0.2.tar.gz: acomea.contact-0.2/acomea/contact/utils/update.py <==
# coding: utf-8
"""
contacts update utils
"""
import logging
import datetime

from django.db import connection, DatabaseError, IntegrityError
from django.db.models import Q
from django.contrib.auth.models import User
from django.core.exceptions import ObjectDoesNotExist
from django.conf import settings

from acomea.contact.models import Contact, Email
from acomea.profilo.models import AcomeaProfilo

log = logging.getLogger("acomea.contact")


def update_from_user():
    """
    aggiorna le entries del modello 'contact' con le
    corrispondenze del modello User
    """
    users_with_email = User.objects.exclude(email__exact="")
    counter = 0
    profilo_dne = 0
    for user in users_with_email:
        try:
            email = Email.objects.get(email=user.email)
            contact = email.contact
            contact.user = user
            for _email in contact.emails.exclude(email__exact=user.email):
                _email.default = False
                _email.save()
            email.default = True
            email.save()
            contact.save()

        except Email.DoesNotExist:
            print "Email object w/ email: %s does not exist" % user.email
            continue

        # controllo in piu' (c'è già l'unique=True nel campo 'email'
        # del modello Email)
        except Email.MultipleObjectsReturned:
            print "Multiple Email object w/ email: %s" % user.email
            continue

        contact.auth_trattamento_dati = True

        # bonifica aut. invio mat. commerciale: se il contact ha la data di
        # disiscrizione a None, metto a True auth_materiale_commerciale
        if contact.date_unsubscription is None:
            contact.auth_materiale_commerciale = True

        contact.bonifica = True
        contact.save()

        try:
            if user.profilo:
                contact.auth_materiale_commerciale = user.profilo.auth_analisi
                contact.auth_societa_terze = user.profilo.auth_societa_terze
                contact.save()
                counter += 1
        except AcomeaProfilo.DoesNotExist:
            print "l'utente %s non ha alcun profilo associato" % user.username
            profilo_dne += 1
            continue
    # print "Aggiornati %d contatti da users" % counter
    print "utenti con profili associati aggiornati: %d" % counter
    print "utenti senza profili associati: %d" % profilo_dne


def set_bonifica(contact):
    """
    setta il flag "bonifica" dell'instanca contact (devono essere True sia 'auth_trattamento_dati',
    sia 'auth_materiale_commerciale'
    :param contact_instance: instance of Contact object
    """
    try:
        contact.bonifica = contact.auth_trattamento_dati and contact.auth_materiale_commerciale
        contact.save()
    except DatabaseError as e:
        log.error("Errore bonifica contatto id %d - errore: %s" % (contact.id, e.message))
        pass


def set_contact_in_registration_from_tracerequest(user, instance):
    cleaned_data = dict(
        email=instance.email,
        first_name=instance.first_name,
        last_name=instance.last_name,
    )
    return set_contact_in_registration(user, cleaned_data)


def set_contact_in_registration(user, cleaned_data):
    """
    setta la OneToOne allo User per l'istanza contact al termine della registrazione:
    - se c'è già un Contact con la email dello user, recupero e effettua l'associazione
    - se non c'è, crea un nuovo contatto con quella mail e associo lo user
    in entrambe i casi il gruppo associato sarà 'Utenti Registrati AR'.
    :param user: istanza oggetto User
    """
    email = cleaned_data.get('email')
    auth_trattamento_dati = cleaned_data.get('auth_trattamento_dati', False) or False
    auth_materiale_commerciale = cleaned_data.get('auth_materiale_commerciale', False) or False
    auth_societa_terze = cleaned_data.get('auth_societa_terze', False) or False
    trace_request_plugin = None
    if isinstance(auth_trattamento_dati, (str, unicode)):
        auth_trattamento_dati = True if auth_trattamento_dati == "True" else False
    if isinstance(auth_materiale_commerciale, (str, unicode)):
        auth_materiale_commerciale = True if auth_materiale_commerciale == "True" else False
    if isinstance(auth_societa_terze, (str, unicode)):
        auth_societa_terze = True if auth_societa_terze == "True" else False
    # Memorizzazione
    try:
        email = Email.objects.get(email=email)
    except Email.DoesNotExist:
        email = Email(email=email)
    try:
        contact = email.contact
    except Contact.DoesNotExist:
        contact = Contact()
    contact.first_name = user.first_name
    contact.last_name = user.last_name
    contact.auth_trattamento_dati = auth_trattamento_dati
    contact.auth_materiale_commerciale = auth_materiale_commerciale
    contact.auth_societa_terze = auth_societa_terze
    if trace_request_plugin:
        contact.trace_request_plugin = trace_request_plugin
    if contact.pk is None:
       contact.bonifica = False
    contact.save()
    email.default = True

    try:
        contact.emails.add(email)

    except IntegrityError, e:
        log.debug(
            "email %s gia' associata al "
            "contatto %s" % (
                email.email,
                str(contact.id)
            )
        )
    try:
        contact.user = user
        contact.save()
    except (IntegrityError, DatabaseError) as e:
        log.error(
            "errore associazione contact %s con "
            "user %s. errore: %s" % (
                str(contact),
                str(user),
                e.message
            )
        )
    update_date_subscription_and_email(contact)
    return contact


def update_date_subscription_and_email(contact, is_lead_registration=False):
    """

    :param contact:
    :param is_lead_registration:
    :return:
    """
    if not is_lead_registration:
        # fixme:
        # da verificare -> se non si è nel form di registrazione, setta la data di
        # sottoscrizione e salva il contatto
        contact.date_subscription = datetime.datetime.now()
        return
    try:
        user = contact.user
        profilo = user.profilo
    except User.DoesNotExist:
        log.debug(
            "contatto %d non ha associato alcuno user" %
            contact.id
        )
        return
    except AcomeaProfilo.DoesNotExist:
        log.debug(
            "utente %s non ha associato alcun profilo" %
            user.username
        )
        return
    # iscrizione_alla_newsletter = contact.user.profilo.iscrizione_alla_newsletter
    auth_materiale_commerciale = contact.auth_materiale_commerciale
    if auth_materiale_commerciale:
        contact.date_subscription = datetime.datetime.now()
        contact.save()


def set_new_contact_for_user(user):
    """
    Associa un nuovo contatto ad uno user. se lo user ha già
    un contatto associato, verrà sovrascritto
    :param user:
    :return: contact
    """
    contact = Contact()
    contact.first_name = user.first_name
    contact.last_name = user.last_name
    try:
        email = Email.objects.get(email=user.email)
    except Email.DoesNotExist:
        email = Email(email=user.email)
    email.default = True
    email.save()
    contact.emails.add(email)
    contact.user = user
    contact.save()
    return contact


def bonifica_contact_groups_from_rac(queryset=None):
    """
    setta i gruppi contatto "CLIENTE_DISP", "CLIENTE_CONS",
    "Lead", "Utenti Registrati AR" in base allo stato rac e
    al flag profilo is_lead
    :param queryset: rac queryset

    """
    # inside function imports to avoid possible circular imports
    from acomea.contact.models import Group, Contact
    if settings.DEBUG:
        print(
            'bonifica_contact_groups_from_rac - start %s' %
            datetime.datetime.now().strftime("%d/%m/%Y %X")
        )
    else:
        log.info(
            'bonifica_contact_groups_from_rac - start %s' %
            datetime.datetime.now().strftime("%d/%m/%Y %X")
        )
    if not queryset:
        from acomea.profilo.models import RichiestaAttivazioneCliente
        queryset = RichiestaAttivazioneCliente.objects.filter(
            Q(stato__in=('6', '9')) | Q(profilo__is_lead=True)
        )
    group_clienti_disp, c = Group.objects.get_or_create(
        name__iexact="CLIENTI_DISP"
    )
    group_clienti_cons, c = Group.objects.get_or_create(
        name__iexact="CLIENTI_CONS"
    )
    group_utenti_registrati_ar, c = Group.objects.get_or_create(
        name__iexact="Utenti Registrati AR"
    )
    group_lead, c = Group.objects.get_or_create(
        name__iexact="Lead"
    )
    for rac in queryset:
        try:
            if rac.stato == "6":
                rac.profilo.user.contact.groups.add(
                    group_clienti_cons
                )
                rac.profilo.user.contact.groups.remove(
                    group_clienti_disp, group_lead
                )
            elif rac.stato == "9":
                rac.profilo.user.contact.groups.add(
                    group_clienti_disp,
                )
                rac.profilo.user.contact.groups.remove(
                    group_clienti_cons, group_lead
                )
            elif rac.profilo.is_lead:
                rac.profilo.user.contact.groups.add(
                    group_lead
                )
            rac.profilo.user.contact.groups.add(
                group_utenti_registrati_ar
            )
        except ObjectDoesNotExist:
            continue
    if settings.DEBUG:
        print(
            'bonifica_contact_groups_from_rac - end %s' %
            datetime.datetime.now().strftime("%d/%m/%Y %X")
        )
    else:
        log.info(
            'bonifica_contact_groups_from_rac - end %s' %
            datetime.datetime.now().strftime("%d/%m/%Y %X")
        )
